@@ -45,11 +45,9 @@
 
 namespace gnote {
 
-  namespace {
-
   std::string tray_util_get_tooltip_text()
   {
-    std::string tip_text = _("Gnote Notes");
+    std::string tip_text = _("Gnote");
     
     if (Preferences::obj().get<bool>(Preferences::ENABLE_KEYBINDINGS)) {
       std::string shortcut =
@@ -62,7 +60,6 @@ namespace gnote {
     return tip_text;
   }
 
-  }
 
 
   bool                      NoteMenuItem::s_static_inited = false;
@@ -155,14 +152,6 @@ namespace gnote {
     return Gtk::ImageMenuItem::on_leave_notify_event(ev);
   }
 
-  std::string NoteMenuItem::format_for_label (const std::string & name)
-  {
-    // Replace underscores ("_") with double-underscores ("__")
-    // so Note menuitems are not created with mnemonics.
-    return sharp::string_replace_all(name, "-", "--");
-  }
-
-
   std::string NoteMenuItem::get_display_name(const Note::Ptr & note)
   {
     std::string display_name = note->get_title();
@@ -177,7 +166,7 @@ namespace gnote {
       display_name = ellipsify (display_name, max_length);
     }
 
-    return format_for_label(display_name);
+    return display_name;
   }
 
   std::string NoteMenuItem::ellipsify (const std::string & str, size_t max)
@@ -412,7 +401,8 @@ namespace gnote {
     Glib::RefPtr<Gdk::Pixbuf> pixbuf = utils::get_icon("gnote", panel_size);
     set(pixbuf);
 #if GTK_VERSION_GE(2,16)
-    set_tooltip_text(tray_util_get_tooltip_text());
+    gtk_status_icon_set_tooltip_text(gobj(), 
+                                     tray_util_get_tooltip_text().c_str());
 #endif
 
     Gtk::Main::signal_quit().connect(sigc::mem_fun(*this, &TrayIcon::on_exit), 1);
@@ -429,9 +419,9 @@ namespace gnote {
     if(select_first_item) {
       m_tray->tray_menu()->select_first(false);
     }
-    utils::popup_menu(*m_tray->tray_menu(), NULL, 
-                      sigc::bind(sigc::mem_fun(*this, &TrayIcon::get_tray_menu_pos), 
-                                 m_tray->tray_menu()));
+    
+    popup_menu_at_position(*m_tray->tray_menu(), 0, 
+                           gtk_get_current_event_time());
   }
 
   TrayIcon::~TrayIcon()
@@ -446,44 +436,15 @@ namespace gnote {
     show_menu(false);
   }
 
-  void TrayIcon::on_popup_menu(guint button, guint32 /*activate_time*/)
+  void TrayIcon::on_popup_menu(guint button, guint32 activate_time)
   {
     DBG_OUT("popup");
     if(button == 3) {
       Gtk::Menu *menu = get_right_click_menu();
-      utils::popup_menu(*menu, NULL, 
-                        sigc::bind(sigc::mem_fun(*this, &TrayIcon::get_tray_menu_pos), menu));
+      popup_menu_at_position(*menu, button, activate_time);
     }
   }  
 
-
-  void TrayIcon::get_tray_menu_pos(int & x, int &y, bool & push_in, Gtk::Menu * menu)
-  {
-      push_in = true;
-      x = 0;
-      y = 0;
-      
-//      Glib::RefPtr<Gdk::Screen> screen;
-      GdkScreen *cscreen = NULL;
-      Gdk::Rectangle area;
-      GtkOrientation orientation;
-// using the C++ API seems to crash here on the Gdk::Screen.
-//      get_geometry (screen, area, orientation);
-      gtk_status_icon_get_geometry(gobj(), &cscreen, area.gobj(), &orientation);
-      x = area.get_x();
-      y = area.get_y();
-
-      Gtk::Requisition menu_req;
-      menu->size_request (menu_req);
-      if (y + menu_req.height >= gdk_screen_get_height(cscreen)/*screen->get_height()*/) {
-        y -= menu_req.height;
-      }
-      else {
-        y += area.get_height();
-      }
-      DBG_OUT("x = %d, y = %d, push_in = %d", x, y, push_in);
-  }
-
   Gtk::Menu * TrayIcon::get_right_click_menu()
   {
     DBG_OUT("get right click menu");
